@@ -72,11 +72,6 @@ def get_visibility(name: str) -> str:
     return visibility
 
 
-def is_interface(node: nodes.ClassDef) -> bool:
-    # bw compatibility
-    return node.type == "interface"  # type: ignore[no-any-return]
-
-
 def is_exception(node: nodes.ClassDef) -> bool:
     # bw compatibility
     return node.type == "exception"  # type: ignore[no-any-return]
@@ -223,7 +218,6 @@ def infer_node(node: nodes.AssignAttr | nodes.AssignName) -> set[InferenceResult
     """Return a set containing the node annotation if it exists
     otherwise return a set of the inferred types using the NodeNG.infer method.
     """
-
     ann = get_annotation(node)
     try:
         if ann:
